==> nextcloud-13.0.1.tgz: nextcloud/apps/files_external/l10n/nl.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Externe opslag",
    "Personal" : "Persoonlijk",
    "System" : "Systeem",
    "Grant access" : "Sta toegang toe",
    "Error configuring OAuth1" : "Fout bij configureren OAuth1",
    "Please provide a valid app key and secret." : "Geef een geldige app sleutel en geheime sleutel op.",
    "Error configuring OAuth2" : "Fout bij configureren OAuth2",
    "Generate keys" : "Genereer sleutels",
    "Error generating key pair" : "Fout bij genereren sleutelpaar",
    "All users. Type to select user or group." : "Alle gebruikers. Tikken om een gebruiker of groep te selecteren.",
    "(group)" : "(groep)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibiliteit met Mac NFD encoding (traag)",
    "Admin defined" : "Beheerder gedefinieerd",
    "Are you sure you want to delete this external storage?" : "Weet je zeker dat je deze externe opslag wilt verwijderen",
    "Delete storage?" : "Opslag verwijderen?",
    "Saved" : "Bewaard",
    "Saving..." : "Bewaren...",
    "Save" : "Bewaren",
    "Empty response from the server" : "Lege reactie van de server",
    "Couldn't access. Please log out and in again to activate this mount point" : "Kon geen toegang krijgen. Log uit en opnieuw in om dit koppelpunt te activeren",
    "Couldn't get the information from the remote server: {code} {type}" : "Kon geen informatie van de externe server krijgen: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Kon geen overzicht met externe koppelpunten krijgen: {type}",
    "There was an error with message: " : "Er was een fout met de volgende melding:",
    "External mount error" : "Extern koppelpunt fout",
    "external-storage" : "externe opslag",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Kon geen overzicht met Windows netwerk koppelpunten krijgen: Maak de server reactie leeg",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Sommige van de geconfigureerde koppelpunten zijn niet verbonden. Klik op de rode rij(en) voor meer informatie",
    "Please enter the credentials for the {mount} mount" : "Geef de inloggegevens op voor de {mount} mount",
    "Username" : "Gebruikersnaam",
    "Password" : "Wachtwoord",
    "Credentials saved" : "Inloggegevens opgeslagen",
    "Credentials saving failed" : "Opslaan inloggegevens mislukt",
    "Credentials required" : "Inloggegevens vereist",
    "Storage with ID \"%d\" not found" : "Opslag met ID \"%d\" niet gevonden",
    "Invalid backend or authentication mechanism class" : "Ongeldige backend of authenticatie mechanisme klasse",
    "Invalid mount point" : "Ongeldig aankoppelpunt",
    "Objectstore forbidden" : "Objectopslag verboden",
    "Invalid storage backend \"%s\"" : "Ongeldig opslagsysteem \"%s\"",
    "Not permitted to use backend \"%s\"" : "Niet toegestaan om \"%s\" te gebruiken",
    "Not permitted to use authentication mechanism \"%s\"" : "Niet toegestaan om authenticatiemechanisme \"%s\" te gebruiken",
    "Unsatisfied backend parameters" : "Onvoldoende backend parameters",
    "Unsatisfied authentication mechanism parameters" : "Onvoldoende authenticatiemechanisme parameters",
    "Insufficient data: %s" : "Onvoldoende gegevens: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Opslag met ID \"%d\" is niet door gebruikers te bewerken",
    "Access key" : "Access Key",
    "Secret key" : "Geheime sleutel",
    "Builtin" : "Ingebouwd",
    "None" : "Geen",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Client secret",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "Naam tenant",
    "Identity endpoint URL" : "Identiteiten endpoint URL",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domein",
    "Rackspace" : "Rackspace",
    "API key" : "API sleutel",
    "Global credentials" : "Algemene inloggegevens",
    "Log-in credentials, save in database" : "Inloggegevens, bewaren in de database",
    "Username and password" : "Gebruikersnaam en wachtwoord",
    "Log-in credentials, save in session" : "Inloggegevens, opslaan in sessie",
    "User entered, store in database" : "Gebruiker opgegeven, opslaan in de database",
    "RSA public key" : "RSA publieke sleutel",
    "Public key" : "Publieke sleutel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Hostnaam",
    "Port" : "Poort",
    "Region" : "Regio",
    "Enable SSL" : "Activeren SSL",
    "Enable Path Style" : "Activeren pad stijl",
    "Legacy (v2) authentication" : "Legacy (v2) authenticatie",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Externe submap",
    "Secure https://" : "Secure https://",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Secure ftps://",
    "Local" : "Lokaal",
    "Location" : "Locatie",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP met geheime sleutel inlog",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Share",
    "SMB / CIFS using OC login" : "SMB / CIFS via OC inlog",
    "Username as share" : "Gebruikersnaam als share",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Servicenaam",
    "Request timeout (seconds)" : "Aanvraag time-out (seconds)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Curl ondersteuning in PHP is niet ingeschakeld of geïnstalleerd. Mounten van %s is niet mogelijk. Vraag je systeembeheerder dit te installeren.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP ondersteuning in PHP is niet ingeschakeld of geïnstalleerd. Mounten van %s is niet mogelijk. Vraag je beheerder dit te installeren.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" is niet geïnstalleerd. Mounten van %s is niet mogelijk. Vraag je beheerder om dit te installeren.",
    "External storage support" : "Externe opslag ondersteuning",
    "No external storage configured or you don't have the permission to configure them" : "Geen externe opslag geconfigureerd of je hebt geen toestemming om deze te configureren",
    "Name" : "Naam",
    "Storage type" : "Opslagtype",
    "Scope" : "Scope",
    "Enable encryption" : "Versleuteling inschakelen",
    "Enable previews" : "Activeren voorbeelden",
    "Enable sharing" : "Activeren delen",
    "Check for changes" : "Controleren op wijzigingen",
    "Never" : "Nooit",
    "Once every direct access" : "Een keer bij elke directe toegang",
    "Folder name" : "Mapnaam",
    "External storage" : "Externe opslag",
    "Authentication" : "Authenticatie",
    "Configuration" : "Configuratie",
    "Available for" : "Beschikbaar voor",
    "Click to recheck the configuration" : "Klik om de configuratie opnieuw te controleren",
    "Add storage" : "Toevoegen opslag",
    "Advanced settings" : "Geavanceerde instellingen",
    "Delete" : "Verwijder",
    "Allow users to mount external storage" : "Sta gebruikers toe om een externe opslag aan te koppelen",
    "Allow users to mount the following external storage" : "Sta gebruikers toe de volgende externe opslag aan te koppelen",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Binnenhalen van de aanvraag token is mislukt. Controleer dat je app sleutel en geheim correct zijn.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Binnenhalen van de toegangstoken is mislukt. Controleer dat je app sleutel en geheim correct zijn.",
    "Step 1 failed. Exception: %s" : "Stap 1 mislukt. Uitzondering: %s",
    "Step 2 failed. Exception: %s" : "Stap 2 mislukt. Uitzondering: %s",
    "Dropbox App Configuration" : "Dropbox App Configuratie",
    "Google Drive App Configuration" : "Google Drive App Configuratie",
    "OpenStack" : "OpenStack",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "No external storage configured" : "Geen externe opslag geconfigureerd",
    "You can add external storages in the personal settings" : "Je kunt externe opslag toevoegen in persoonlijke instellingen",
    "Are you sure you want to delete this external storage" : "Weet je zeker dat je de externe opslag wilt verwijderen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.1.tgz: nextcloud/apps/files_external/l10n/nl.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Externe opslag",
    "Personal" : "Persoonlijk",
    "System" : "Systeem",
    "Grant access" : "Sta toegang toe",
    "Error configuring OAuth1" : "Fout bij configureren OAuth1",
    "Please provide a valid app key and secret." : "Geef een geldige app sleutel en geheime sleutel op.",
    "Error configuring OAuth2" : "Fout bij configureren OAuth2",
    "Generate keys" : "Genereer sleutels",
    "Error generating key pair" : "Fout bij genereren sleutelpaar",
    "All users. Type to select user or group." : "Alle gebruikers. Tikken om een gebruiker of groep te selecteren.",
    "(group)" : "(groep)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibiliteit met Mac NFD encoding (traag)",
    "Admin defined" : "Beheerder gedefinieerd",
    "Are you sure you want to delete this external storage?" : "Weet je zeker dat je deze externe opslag wilt verwijderen",
    "Delete storage?" : "Opslag verwijderen?",
    "Saved" : "Bewaard",
    "Saving..." : "Bewaren...",
    "Save" : "Bewaren",
    "Empty response from the server" : "Lege reactie van de server",
    "Couldn't access. Please log out and in again to activate this mount point" : "Kon geen toegang krijgen. Log uit en opnieuw in om dit koppelpunt te activeren",
    "Couldn't get the information from the remote server: {code} {type}" : "Kon geen informatie van de externe server krijgen: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Kon geen overzicht met externe koppelpunten krijgen: {type}",
    "There was an error with message: " : "Er was een fout met de volgende melding:",
    "External mount error" : "Extern koppelpunt fout",
    "external-storage" : "externe opslag",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Kon geen overzicht met Windows netwerk koppelpunten krijgen: Maak de server reactie leeg",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Sommige van de geconfigureerde koppelpunten zijn niet verbonden. Klik op de rode rij(en) voor meer informatie",
    "Please enter the credentials for the {mount} mount" : "Geef de inloggegevens op voor de {mount} mount",
    "Username" : "Gebruikersnaam",
    "Password" : "Wachtwoord",
    "Credentials saved" : "Inloggegevens opgeslagen",
    "Credentials saving failed" : "Opslaan inloggegevens mislukt",
    "Credentials required" : "Inloggegevens vereist",
    "Storage with ID \"%d\" not found" : "Opslag met ID \"%d\" niet gevonden",
    "Invalid backend or authentication mechanism class" : "Ongeldige backend of authenticatie mechanisme klasse",
    "Invalid mount point" : "Ongeldig aankoppelpunt",
    "Objectstore forbidden" : "Objectopslag verboden",
    "Invalid storage backend \"%s\"" : "Ongeldig opslagsysteem \"%s\"",
    "Not permitted to use backend \"%s\"" : "Niet toegestaan om \"%s\" te gebruiken",
    "Not permitted to use authentication mechanism \"%s\"" : "Niet toegestaan om authenticatiemechanisme \"%s\" te gebruiken",
    "Unsatisfied backend parameters" : "Onvoldoende backend parameters",
    "Unsatisfied authentication mechanism parameters" : "Onvoldoende authenticatiemechanisme parameters",
    "Insufficient data: %s" : "Onvoldoende gegevens: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Opslag met ID \"%d\" is niet door gebruikers te bewerken",
    "Access key" : "Access Key",
    "Secret key" : "Geheime sleutel",
    "Builtin" : "Ingebouwd",
    "None" : "Geen",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Client secret",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "Naam tenant",
    "Identity endpoint URL" : "Identiteiten endpoint URL",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domein",
    "Rackspace" : "Rackspace",
    "API key" : "API sleutel",
    "Global credentials" : "Algemene inloggegevens",
    "Log-in credentials, save in database" : "Inloggegevens, bewaren in de database",
    "Username and password" : "Gebruikersnaam en wachtwoord",
    "Log-in credentials, save in session" : "Inloggegevens, opslaan in sessie",
    "User entered, store in database" : "Gebruiker opgegeven, opslaan in de database",
    "RSA public key" : "RSA publieke sleutel",
    "Public key" : "Publieke sleutel",
    "RSA private key" : "RSA privésleutel",
    "Private key" : "Privésleutel",
    "Kerberos ticket" : "Kerberos ticket",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Hostnaam",
    "Port" : "Poort",
    "Region" : "Regio",
    "Enable SSL" : "Activeren SSL",
    "Enable Path Style" : "Activeren pad stijl",
    "Legacy (v2) authentication" : "Legacy (v2) authenticatie",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Externe submap",
    "Secure https://" : "Secure https://",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Secure ftps://",
    "Local" : "Lokaal",
    "Location" : "Locatie",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP met geheime sleutel inlog",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Share",
    "SMB / CIFS using OC login" : "SMB / CIFS via OC inlog",
    "Username as share" : "Gebruikersnaam als share",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Servicenaam",
    "Request timeout (seconds)" : "Aanvraag time-out (seconds)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Curl ondersteuning in PHP is niet ingeschakeld of geïnstalleerd. Mounten van %s is niet mogelijk. Vraag je systeembeheerder dit te installeren.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP ondersteuning in PHP is niet ingeschakeld of geïnstalleerd. Mounten van %s is niet mogelijk. Vraag je beheerder dit te installeren.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" is niet geïnstalleerd. Mounten van %s is niet mogelijk. Vraag je beheerder om dit te installeren.",
    "External storage support" : "Externe opslag ondersteuning",
    "No external storage configured or you don't have the permission to configure them" : "Geen externe opslag geconfigureerd of je hebt geen toestemming om deze te configureren",
    "Name" : "Naam",
    "Storage type" : "Opslagtype",
    "Scope" : "Scope",
    "Enable encryption" : "Versleuteling inschakelen",
    "Enable previews" : "Activeren voorbeelden",
    "Enable sharing" : "Activeren delen",
    "Check for changes" : "Controleren op wijzigingen",
    "Never" : "Nooit",
    "Once every direct access" : "Een keer bij elke directe toegang",
    "Folder name" : "Mapnaam",
    "External storage" : "Externe opslag",
    "Authentication" : "Authenticatie",
    "Configuration" : "Configuratie",
    "Available for" : "Beschikbaar voor",
    "Click to recheck the configuration" : "Klik om de configuratie opnieuw te controleren",
    "Add storage" : "Toevoegen opslag",
    "Advanced settings" : "Geavanceerde instellingen",
    "Allow users to mount external storage" : "Sta gebruikers toe om een externe opslag aan te koppelen",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Binnenhalen van de aanvraag token is mislukt. Controleer dat je app sleutel en geheim correct zijn.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Binnenhalen van de toegangstoken is mislukt. Controleer dat je app sleutel en geheim correct zijn.",
    "Step 1 failed. Exception: %s" : "Stap 1 mislukt. Uitzondering: %s",
    "Step 2 failed. Exception: %s" : "Stap 2 mislukt. Uitzondering: %s",
    "Dropbox App Configuration" : "Dropbox App Configuratie",
    "Google Drive App Configuration" : "Google Drive App Configuratie",
    "OpenStack" : "OpenStack",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "No external storage configured" : "Geen externe opslag geconfigureerd",
    "You can add external storages in the personal settings" : "Je kunt externe opslag toevoegen in persoonlijke instellingen",
    "Delete" : "Verwijder",
    "Allow users to mount the following external storage" : "Sta gebruikers toe de volgende externe opslag aan te koppelen",
    "Are you sure you want to delete this external storage" : "Weet je zeker dat je de externe opslag wilt verwijderen"
},
"nplurals=2; plural=(n != 1);");
